<?php



require_once 'Classes/General/File.php';



/**
 * This class is a tar file builder. Though the actual work of
 * building the tar file is done by execing tar. We use this
 * algorithm by giving it a data directory to compress the files
 * from, the names of all the files under that path we want to
 * add to the tar file, and the name and path to the tar file
 * we want to create.
 **/
class TarBuilder
{
  // PUBLIC

    public function __construct()
    {
      $this->tar_file = new File();
      $this->files = Array();
      $this->src_dir = null;
    }

    public function AddFile( File $new_file ) { $this->files[] = $new_file; }
    public function SetTarFile( File $s_tar_file ) { $this->tar_file = $s_tar_file; }

    public function SetSrcDir( Dir $s_src_dir ) { $this->src_dir = $s_src_dir; }

    //! Call exec to run tar and create our tarfile.
    public function Execute()
    {
      $cwd = getcwd();
      if( $this->src_dir != null )
      {
        chdir( $this->src_dir->GetPath() );
	for( $i = 0; $i < count( $this->files ) ; $i ++ )
	  $this->files[$i]->SubtractBasePath( $this->src_dir );
      }

      $command = 'tar --dereference -cf ' . $this->tar_file->GetFullPath() . ' ';

      foreach( $this->files as $next_file )
	$command .= $next_file->GetFullPath() . ' ';

//       echo 'tar command is ' . $command . ' <br> ';
      
      $ret_val = '';
      $output_array = Array();
      $last_line = exec( $command, $output_array, $ret_val );

      if( !$this->tar_file->Exists() )
        throw new GZ_Exception( 'No tar file created', 'TarBuilder::Execute' );
      
      chdir( $cwd );
    }

  // PRIVATE

    private $tar_file;
    private $src_dir;
    private $filenames;
};


?>